## 1.5.6.1.20250123 (2025-01-23)

zstd: pin version (#13428)

## 1.5.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 1.5.0.3 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.5.0.2 (2023-03-24)

[zstd] Add ZSTD_(max_)threads_count methods (#9938)

Closes: #9935

## 1.5.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.5.0.0 (2023-02-01)

Add stubs for `zstd` (#9484)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

